@@ -4,7 +4,7 @@
  * GChemPaint library
  * fragment.h 
  *
- * Copyright (C) 2002-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -43,6 +43,8 @@ class ChargeTextTag: public gccv::PositionTextTag
 public:
 	ChargeTextTag (double size);
 	virtual ~ChargeTextTag ();
+
+	TextTag *Restrict (TextTag *tag);
 };
 
 class StoichiometryTextTag: public gccv::PositionTextTag
@@ -50,6 +52,8 @@ class StoichiometryTextTag: public gccv::PositionTextTag
 public:
 	StoichiometryTextTag (double size);
 	virtual ~StoichiometryTextTag ();
+
+	TextTag *Restrict (TextTag *tag);
 };
 
 class FragmentAtom;
@@ -116,7 +120,7 @@ the framework when editing the fragment.
 /*!
 @param node a pointer to the xmlNode containing the serialized fragment.
 
-Used to load a frafment in memory. The Fragment must already exist.
+Used to load a fragment in memory. The Fragment must already exist.
 @return true on succes, false otherwise.
 */
 	bool Load (xmlNodePtr node);
@@ -191,15 +195,10 @@ is not updated.
 On input \a Pos can be one of POSITION_E, POSITION_N,... or 0xff, in which case,
 it will be given a default value. \a x and \a y are set to the position where the charge
 sign should be displayed usding the alignment code returned by this method.
-@return a number to set how the charge symbol should be aligned relative to its
-position. Possible values are:
-- −2: center top.
-- −1: right.
--  0: center.
--  1: left.
--  2: center bottom.
+@return the anchor for the charge symbol. On error, gccv::AnchorCenter is used as
+the returned value.
 */
-	int GetChargePosition (FragmentAtom *pAtom, unsigned char &Pos, double Angle, double &x, double &y);
+	gccv::Anchor GetChargePosition (FragmentAtom *pAtom, unsigned char &Pos, double Angle, double &x, double &y);
 /*!
 @param x the x position.
 @param y the y position.
@@ -249,6 +248,9 @@ Changes the order of the symbols if necessary when a bond is at an extremity
 of the fragment.
 */
 	void Update ();
+	gccv::Item *GetChargeItem ();
+
+	std::string Name ();
 
 	typedef enum {
 		Invalid,
@@ -272,11 +274,10 @@ private:
 private:
 	FragmentAtom *m_Atom;
 	unsigned m_BeginAtom, m_EndAtom;
-	int m_lbearing;
+	double m_lbearing;
 	double m_CHeight;
 	bool m_Inversable;
 
-GCU_RO_PROP (gccv::Text *, TextItem)
 GCU_RO_PROP (Validity, Valid)
 GCU_PROP (FragmentMode, Mode)
 };
