@@ -90,6 +90,12 @@ static int get_fontweight (PangoWeight val)
 		case PANGO_WEIGHT_BOLD: return 7;
 		case PANGO_WEIGHT_ULTRABOLD: return 8;
 		case PANGO_WEIGHT_HEAVY: return 9;
+#if PANGO_VERSION_MAJOR > 1 || PANGO_VERSION_MINOR >= 24
+		case PANGO_WEIGHT_THIN: return 1;
+		case PANGO_WEIGHT_BOOK: return 38;
+		case PANGO_WEIGHT_MEDIUM: return 5;
+		case PANGO_WEIGHT_ULTRAHEAVY: return 10;
+#endif
 		default: return 4;
 	}
 }
@@ -124,39 +130,17 @@ static double get_fontsize (double val) {return (double) val / (double) PANGO_SC
 static void on_compression_changed (GtkSpinButton *btn, Application *App)
 {
 	CompressionLevel = gtk_spin_button_get_value_as_int (btn);
-#ifdef HAVE_GO_CONF_SYNC
 	GOConfNode *node = go_conf_get_node (App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 	go_conf_set_int (node, "compression", CompressionLevel);
 	go_conf_free_node (node);
-#else
-	GConfClient *conf_client = gconf_client_get_default ();
-	GError *error = NULL;
-	gconf_client_set_int (conf_client, ROOTDIR"compression", CompressionLevel, &error);
-	if (error) {
-		g_message("GConf failed: %s", error->message);
-		g_error_free (error);
-	}
-	g_object_unref (conf_client);
-#endif
 }
 
-static void on_tearable_mendeleiev_changed (GtkToggleButton *btn, Application *App)
+static void on_invert_wedge_hashes_changed (GtkToggleButton *btn, Application *App)
 {
-	TearableMendeleiev = gtk_toggle_button_get_active (btn);
-#ifdef HAVE_GO_CONF_SYNC
+	InvertWedgeHashes = gtk_toggle_button_get_active (btn);
 	GOConfNode *node = go_conf_get_node (App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
-	go_conf_set_bool (node, "tearable-mendeleiev", TearableMendeleiev);
+	go_conf_set_bool (node, "invert-wedge-hashes", InvertWedgeHashes);
 	go_conf_free_node (node);
-#else
-	GConfClient *conf_client = gconf_client_get_default ();
-	GError *error = NULL;
-	gconf_client_set_bool (conf_client, ROOTDIR"tearable-mendeleiev", TearableMendeleiev, &error);
-	if (error) {
-		g_message("GConf failed: %s", error->message);
-		g_error_free (error);
-	}
-	g_object_unref (conf_client);
-#endif
 }
 
 static void on_new_theme (PrefsDlg *dlg)
@@ -284,13 +268,13 @@ static void on_name_changed (GtkEntry *entry, PrefsDlg *dlg)
 	PrefsDlgPrivate::OnThemeNameChanged (dlg, gtk_entry_get_text (entry));
 }
 
-static bool on_name_focused_out (GtkEntry *entry, GdkEventFocus *event, PrefsDlg *dlg)
+static bool on_name_focused_out (GtkEntry *entry, G_GNUC_UNUSED GdkEventFocus *event, PrefsDlg *dlg)
 {
 	PrefsDlgPrivate::OnThemeNameChanged (dlg, gtk_entry_get_text (entry));
 	return false;
 }
 
-static bool on_delete_event (GtkWidget* widget, GdkEvent *event, PrefsDlg* dlg)
+static bool on_delete_event (GtkWidget* widget, G_GNUC_UNUSED GdkEvent *event, PrefsDlg* dlg)
 {
 	bool res = PrefsDlgPrivate::CheckError (dlg);
 	if (res) {
@@ -307,84 +291,80 @@ static void on_default_theme_changed (GtkComboBox *box, PrefsDlg* dlg)
 }
 
 PrefsDlg::PrefsDlg (Application *pApp):
-	Dialog (pApp, GLADEDIR"/preferences.glade", "preferences", pApp),
+	Dialog (pApp, UIDIR"/preferences.ui", "preferences", GETTEXT_PACKAGE, pApp),
 	Object (),
 	m_CurTheme (NULL),
 	m_Path (NULL)
 {
-	if (!xml) {
-		delete this;
-		return;
-	}
 	g_signal_connect (G_OBJECT (dialog), "delete-event", G_CALLBACK (on_delete_event), this);
 	// compression level
-	GtkWidget *w = glade_xml_get_widget (xml, "compression");
+	GtkWidget *w = GetWidget ("compression");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), CompressionLevel);
 	g_signal_connect (G_OBJECT (w), "value-changed", G_CALLBACK (on_compression_changed), pApp);
-	// tearable table of the elements
-	w = glade_xml_get_widget (xml, "tearable-mendeleiev-btn");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), TearableMendeleiev);
-	g_signal_connect (G_OBJECT (w), "toggled", G_CALLBACK (on_tearable_mendeleiev_changed), pApp);
+	// invert hashed bonds or not
+	w = GetWidget ("invert-wedge-hashes");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), InvertWedgeHashes);
+	g_signal_connect (G_OBJECT (w), "toggled", G_CALLBACK (on_invert_wedge_hashes_changed), pApp);
 	// retrieve theme widgets and set signals
-	m_BondLengthBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "bond-length-btn"));
+	m_BondLengthBtn = GTK_SPIN_BUTTON (GetWidget ("bond-length-btn"));
 	g_signal_connect (G_OBJECT (m_BondLengthBtn), "value-changed", G_CALLBACK (on_bond_length_changed), this);
-	m_BondAngleBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "bond-angle-btn"));
+	m_BondAngleBtn = GTK_SPIN_BUTTON (GetWidget ("bond-angle-btn"));
 	g_signal_connect (G_OBJECT (m_BondAngleBtn), "value-changed", G_CALLBACK (on_bond_angle_changed), this);
-	m_BondWidthBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "bond-width-btn"));
+	m_BondWidthBtn = GTK_SPIN_BUTTON (GetWidget ("bond-width-btn"));
 	g_signal_connect (G_OBJECT (m_BondWidthBtn), "value-changed", G_CALLBACK (on_bond_width_changed), this);
-	m_BondDistBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "bond-dist-btn"));
+	m_BondDistBtn = GTK_SPIN_BUTTON (GetWidget ("bond-dist-btn"));
 	g_signal_connect (G_OBJECT (m_BondDistBtn), "value-changed", G_CALLBACK (on_bond_dist_changed), this);
-	m_StereoBondWidthBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "stereo-width-btn"));
+	m_StereoBondWidthBtn = GTK_SPIN_BUTTON (GetWidget ("stereo-width-btn"));
 	g_signal_connect (G_OBJECT (m_StereoBondWidthBtn), "value-changed", G_CALLBACK (on_stereo_bond_width_changed), this);
-	m_HashWidthBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "hash-width-btn"));
+	m_HashWidthBtn = GTK_SPIN_BUTTON (GetWidget ("hash-width-btn"));
 	g_signal_connect (G_OBJECT (m_HashWidthBtn), "value-changed", G_CALLBACK (on_hash_width_changed), this);
-	m_HashDistBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "hash-dist-btn"));
+	m_HashDistBtn = GTK_SPIN_BUTTON (GetWidget ("hash-dist-btn"));
 	g_signal_connect (G_OBJECT (m_HashDistBtn), "value-changed", G_CALLBACK (on_hash_dist_changed), this);
 	// add font selector
 	m_FontSel = GCP_FONT_SEL (g_object_new (GCP_FONT_SEL_TYPE, NULL));
-	w = glade_xml_get_widget (xml, "atom-font-box");
-	gtk_box_pack_start_defaults (GTK_BOX (w), GTK_WIDGET (m_FontSel));
+	w = GetWidget ("atom-font-box");
+	gtk_box_pack_start (GTK_BOX (w), GTK_WIDGET (m_FontSel), true, true, 0);
 	m_FontChanged = g_signal_connect (G_OBJECT (m_FontSel), "changed", G_CALLBACK (on_font_changed), this);
 	// add text font selector
 	m_TextFontSel = GCP_FONT_SEL (g_object_new (GCP_FONT_SEL_TYPE, NULL));
-	w = glade_xml_get_widget (xml, "text-box");
-	gtk_box_pack_start_defaults (GTK_BOX (w), GTK_WIDGET (m_TextFontSel));
+	w = GetWidget ("text-box");
+	gtk_box_pack_start (GTK_BOX (w), GTK_WIDGET (m_TextFontSel), true, true, 0);
 	m_TextFontChanged = g_signal_connect (G_OBJECT (m_TextFontSel), "changed", G_CALLBACK (on_text_font_changed), this);
 	// arrow spin buttons
-	m_ArrowLengthBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "arrow-length-btn"));
+	m_ArrowLengthBtn = GTK_SPIN_BUTTON (GetWidget ("arrow-length-btn"));
 	g_signal_connect (G_OBJECT (m_ArrowLengthBtn), "value-changed", G_CALLBACK (on_arrow_length_changed), this);
-	m_ArrowWidthBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "arrow-width-btn"));
+	m_ArrowWidthBtn = GTK_SPIN_BUTTON( GetWidget ("arrow-width-btn"));
 	g_signal_connect (G_OBJECT (m_ArrowWidthBtn), "value-changed", G_CALLBACK (on_arrow_width_changed), this);
-	m_ArrowDistBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "arrow-dist-btn"));
+	m_ArrowDistBtn = GTK_SPIN_BUTTON (GetWidget ("arrow-dist-btn"));
 	g_signal_connect (G_OBJECT (m_ArrowDistBtn), "value-changed", G_CALLBACK (on_arrow_dist_changed), this);
-	m_ArrowPaddingBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "arrow-padding-btn"));
+	m_ArrowPaddingBtn = GTK_SPIN_BUTTON (GetWidget ("arrow-padding-btn"));
 	g_signal_connect (G_OBJECT (m_ArrowPaddingBtn), "value-changed", G_CALLBACK (on_arrow_padding_changed), this);
-	m_ArrowHeadABtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "arrow-headA-btn"));
+	m_ArrowHeadABtn = GTK_SPIN_BUTTON (GetWidget ("arrow-headA-btn"));
 	g_signal_connect (G_OBJECT (m_ArrowHeadABtn), "value-changed", G_CALLBACK (on_arrow_headA_changed), this);
-	m_ArrowHeadBBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "arrow-headB-btn"));
+	m_ArrowHeadBBtn = GTK_SPIN_BUTTON (GetWidget ("arrow-headB-btn"));
 	g_signal_connect (G_OBJECT (m_ArrowHeadBBtn), "value-changed", G_CALLBACK (on_arrow_headB_changed), this);
-	m_ArrowHeadCBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "arrow-headC-btn"));
+	m_ArrowHeadCBtn = GTK_SPIN_BUTTON (GetWidget ("arrow-headC-btn"));
 	g_signal_connect (G_OBJECT (m_ArrowHeadCBtn), "value-changed", G_CALLBACK (on_arrow_headC_changed), this);
-	m_ScaleBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "scale-btn"));
+	m_ScaleBtn = GTK_SPIN_BUTTON (GetWidget ("scale-btn"));
 	g_signal_connect (G_OBJECT (m_ScaleBtn), "value-changed", G_CALLBACK (on_scale), this);
-	m_PaddingBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "padding-btn"));
+	m_PaddingBtn = GTK_SPIN_BUTTON (GetWidget ("padding-btn"));
 	g_signal_connect (G_OBJECT (m_PaddingBtn), "value-changed", G_CALLBACK (on_padding), this);
-	m_ObjectPaddingBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "object-padding-btn"));
+	m_ObjectPaddingBtn = GTK_SPIN_BUTTON (GetWidget ("object-padding-btn"));
 	g_signal_connect (G_OBJECT (m_ObjectPaddingBtn), "value-changed", G_CALLBACK (on_object_padding), this);
-	m_StoichPaddingBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "stoich-padding-btn"));
+	m_StoichPaddingBtn = GTK_SPIN_BUTTON (GetWidget ("stoich-padding-btn"));
 	g_signal_connect (G_OBJECT (m_StoichPaddingBtn), "value-changed", G_CALLBACK (on_stoich_padding), this);
-	m_SignPaddingBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "sign-padding-btn"));
+	m_SignPaddingBtn = GTK_SPIN_BUTTON (GetWidget ("sign-padding-btn"));
 	g_signal_connect (G_OBJECT (m_SignPaddingBtn), "value-changed", G_CALLBACK (on_sign_padding), this);
-	m_ChargeSizeBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "charge-size-btn"));
+	m_ChargeSizeBtn = GTK_SPIN_BUTTON (GetWidget ("charge-size-btn"));
 	g_signal_connect (G_OBJECT (m_ChargeSizeBtn), "value-changed", G_CALLBACK (on_charge_size), this);
-	m_NameEntry = GTK_ENTRY (glade_xml_get_widget (xml, "name"));
+	m_NameEntry = GTK_ENTRY (GetWidget ("name"));
 	gtk_entry_set_text (m_NameEntry, _("Default"));
 	m_NameActivate = g_signal_connect (G_OBJECT (m_NameEntry), "activate", G_CALLBACK (on_name_changed), this);
 	m_NameFocusOut = g_signal_connect (G_OBJECT (m_NameEntry), "focus-out-event", G_CALLBACK (on_name_focused_out), this);
 	// get notebook
-	m_Book = GTK_NOTEBOOK (glade_xml_get_widget (xml, "theme-book"));
+	m_Book = GTK_NOTEBOOK (GetWidget ("theme-book"));
 	// create themes list and select active document theme
-	m_ThemesView = GTK_TREE_VIEW (glade_xml_get_widget (xml, "themes"));
+	m_ThemesView = GTK_TREE_VIEW (GetWidget ("themes"));
 	themes = gtk_tree_store_new (1, G_TYPE_STRING);
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (themes), 0, GTK_SORT_ASCENDING);
 	gtk_tree_view_set_model (m_ThemesView, GTK_TREE_MODEL (themes));
@@ -400,7 +380,7 @@ PrefsDlg::PrefsDlg (Application *pApp):
 			default_name = _("Default");
 	Theme *theme, *default_theme = TheThemeManager.GetDefaultTheme ();
 	m_DefaultThemeBox = GTK_COMBO_BOX (gtk_combo_box_new_text ());
-	gtk_table_attach (GTK_TABLE (glade_xml_get_widget (xml, "table1")), GTK_WIDGET (m_DefaultThemeBox), 1, 3, 2, 3,
+	gtk_table_attach (GTK_TABLE (GetWidget ("table1")), GTK_WIDGET (m_DefaultThemeBox), 1, 3, 2, 3,
 													   (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 													   (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
 	int n = 0;
@@ -458,7 +438,7 @@ PrefsDlg::PrefsDlg (Application *pApp):
 	}
 	
 	// add event handler to new theme button
-	g_signal_connect_swapped (G_OBJECT (glade_xml_get_widget (xml, "new-theme")), "clicked", G_CALLBACK (on_new_theme), this);
+	g_signal_connect_swapped (G_OBJECT (GetWidget ("new-theme")), "clicked", G_CALLBACK (on_new_theme), this);
 	gtk_widget_show_all (GTK_WIDGET (dialog));
 }
 
@@ -650,20 +630,9 @@ void PrefsDlg::OnBondLength (double length)
 		m_CurTheme->m_BondLength = length;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "bond-length", length);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"bond-length", length, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -682,20 +651,9 @@ void PrefsDlg::OnBondAngle (double angle)
 		m_CurTheme->m_BondAngle = angle;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "bond-angle", angle);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"bond-angle", angle, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -714,20 +672,9 @@ void PrefsDlg::OnBondWidth (double width)
 		m_CurTheme->m_BondWidth = width;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "bond-width", width);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"bond-width", width, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -746,20 +693,9 @@ void PrefsDlg::OnBondDist (double dist)
 		m_CurTheme->m_BondDist = dist;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "bond-dist", dist);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"bond-dist", dist, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -778,20 +714,9 @@ void PrefsDlg::OnStereoBondWidth (double width)
 		m_CurTheme->m_StereoBondWidth = width;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "stereo-width", width);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"stereo-width", width, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -810,20 +735,9 @@ void PrefsDlg::OnHashWidth (double width)
 		m_CurTheme->m_HashWidth = width;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "hash-width", width);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"hash-width", width, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -842,20 +756,9 @@ void PrefsDlg::OnHashDist (double dist)
 		m_CurTheme->m_HashDist = dist;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "hash-dist", dist);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"hash-dist", dist, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -885,20 +788,9 @@ void PrefsDlg::OnFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_string (node, "font-family", Name);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-				gconf_client_set_string (conf_client, ROOTDIR"font-family", Name, &error);
-				if (error) {
-					g_message("GConf failed: %s", error->message);
-					g_error_free (error);
-				}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -913,20 +805,9 @@ void PrefsDlg::OnFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_int (node, "font-style", get_fontstyle (Style));
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_int (conf_client, ROOTDIR"font-style", get_fontstyle (Style), &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -941,20 +822,9 @@ void PrefsDlg::OnFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_int (node, "font-weight", get_fontweight (Weight));
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_int (conf_client, ROOTDIR"font-weight", get_fontweight (Weight), &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -969,20 +839,9 @@ void PrefsDlg::OnFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_int (node, "font-stretch", get_fontstretch (Stretch));
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_int (conf_client, ROOTDIR"font-stretch", get_fontstretch (Stretch), &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -997,20 +856,9 @@ void PrefsDlg::OnFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_int (node, "font-variant", get_fontvariant (Variant));
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_int (conf_client, ROOTDIR"font-variant", get_fontvariant (Variant), &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1025,20 +873,9 @@ void PrefsDlg::OnFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "font-size", get_fontsize (Size));
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"font-size", get_fontsize (Size), &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1069,20 +906,9 @@ void PrefsDlg::OnTextFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_string (node, "text-font-family", Name);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_string (conf_client, ROOTDIR"text-font-family", Name, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1097,20 +923,9 @@ void PrefsDlg::OnTextFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_int (node, "text-font-style", get_fontstyle (Style));
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_int (conf_client, ROOTDIR"text-font-style", get_fontstyle (Style), &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1125,20 +940,9 @@ void PrefsDlg::OnTextFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_int (node, "text-font-weight", get_fontweight (Weight));
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_int (conf_client, ROOTDIR"text-font-weight", get_fontweight (Weight), &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1153,20 +957,9 @@ void PrefsDlg::OnTextFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_int (node, "text-font-stretch", get_fontstretch (Stretch));
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_int (conf_client, ROOTDIR"text-font-stretch", get_fontstretch (Stretch), &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1181,20 +974,9 @@ void PrefsDlg::OnTextFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_int (node, "text-font-variant", get_fontvariant (Variant));
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_int (conf_client, ROOTDIR"text-font-variant", get_fontvariant (Variant), &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1209,20 +991,9 @@ void PrefsDlg::OnTextFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "text-font-size", get_fontsize (Size));
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"text-font-size", get_fontsize (Size), &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1244,20 +1015,9 @@ void PrefsDlg::OnArrowLength (double length)
 		m_CurTheme->m_ArrowLength = length;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "arrow-length", length);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"arrow-length", length, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1276,20 +1036,9 @@ void PrefsDlg::OnArrowWidth (double width)
 		m_CurTheme->m_ArrowWidth = width;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "arrow-width", width);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"arrow-width", width, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1308,20 +1057,9 @@ void PrefsDlg::OnArrowDist (double dist)
 		m_CurTheme->m_ArrowDist = dist;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "arrow-dist", dist);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"arrow-dist", dist, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1340,20 +1078,9 @@ void PrefsDlg::OnArrowPadding (double padding)
 		m_CurTheme->m_ArrowPadding = padding;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "arrow-padding", padding);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"arrow-padding", padding, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1371,20 +1098,9 @@ void PrefsDlg::OnArrowHeadA (double headA)
 		m_CurTheme->m_ArrowHeadA = headA;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "arrow-headA", headA);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"arrow-headA", headA, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1403,20 +1119,9 @@ void PrefsDlg::OnArrowHeadB (double headB)
 		m_CurTheme->m_ArrowHeadB = headB;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "arrow-headB", headB);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"arrow-headB", headB, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1435,20 +1140,9 @@ void PrefsDlg::OnArrowHeadC (double headC)
 		m_CurTheme->m_ArrowHeadC = headC;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "arrow-headC", headC);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"arrow-headC", headC, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1468,20 +1162,9 @@ void PrefsDlg::OnScale (double scale)
 		m_CurTheme->m_ZoomFactor = zoom;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "scale", scale);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"scale", scale, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1499,20 +1182,9 @@ void PrefsDlg::OnPadding (double padding)
 		m_CurTheme->m_Padding = padding;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "padding", padding);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"padding", padding, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1530,20 +1202,9 @@ void PrefsDlg::OnObjectPadding (double padding)
 		m_CurTheme->m_ObjectPadding = padding;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "object-padding", padding);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"object-padding", padding, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1561,20 +1222,9 @@ void PrefsDlg::OnStoichPadding (double padding)
 		m_CurTheme->m_StoichiometryPadding = padding;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "stoichiometry-padding", padding);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"stoichiometry-padding", padding, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 		break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1592,20 +1242,9 @@ void PrefsDlg::OnSignPadding (double padding)
 		m_CurTheme->m_SignPadding = padding;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "sign-padding", padding);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"sign-padding", padding, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1623,20 +1262,9 @@ void PrefsDlg::OnChargeSize(double size)
 		m_CurTheme->m_ChargeSignSize = size;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
-#ifdef HAVE_GO_CONF_SYNC
 			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 			go_conf_set_double (node, "charge-sign-size", size);
 			go_conf_free_node (node);
-#else
-			GConfClient *conf_client = gconf_client_get_default ();
-			GError *error = NULL;
-			gconf_client_set_float (conf_client, ROOTDIR"charge-sign-size", size, &error);
-			if (error) {
-				g_message("GConf failed: %s", error->message);
-				g_error_free (error);
-			}
-			g_object_unref (conf_client);
-#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1710,20 +1338,9 @@ bool PrefsDlg::CheckError ()
 void PrefsDlg::SetDefaultTheme (char const *name)
 {
 	TheThemeManager.SetDefaultTheme (name);
-#ifdef HAVE_GO_CONF_SYNC
 	GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
 	go_conf_set_string (node, "default-theme", name);
 	go_conf_free_node (node);
-#else
-	GConfClient *conf_client = gconf_client_get_default ();
-	GError *error = NULL;
-	gconf_client_set_string (conf_client, ROOTDIR"default-theme", name, &error);
-	if (error) {
-		g_message("GConf failed: %s", error->message);
-		g_error_free (error);
-	}
-	g_object_unref (conf_client);
-#endif
 }
 
 }	//	namespace gcp
