@@ -27,18 +27,21 @@
 
 #include <gcu/macros.h>
 #include <gcu/gldocument.h>
+#include <gcu/molecule.h>
 #include <openbabel/mol.h>
 
+/*!\file*/
 namespace gcu {
 
 /*! \enum Display3DMode
  3D display mode.
  Possible values are:
 	 - BALL_AND_STICK: use ball and stick representation; atoms are represented by spheres with a radius equal to 20% of
-	 their van der Waals radius and bonds are displayed as cylinders.
+	 their van der Waals radius and bonds are displayed as cylinders Multiple bonds are displayed as multiple cylinders.
 	 - SPACEFILL: use space filling representation; atoms are represented by spheres with a radius equal
 	 their van der Waals radius; bonds are not displayed.
-	 .
+	 - CYLINDERS: only bonds are represented as cylinders, atoms just end the cylinders.
+	 - WIREFRAME: bonds are represented as narrow lines, atoms just end the lines.
 */
 typedef enum
 {
@@ -83,7 +86,7 @@ Displays the molecule using OpenGL.
 /*!
 @return true if the molecule have no atom, false otherwise.
 */
-	bool IsEmpty () {return m_Mol.NumAtoms () == 0;}
+	bool IsEmpty () {return !m_Mol || m_Mol->GetAtomsNumber () == 0;}
 
 /*!
 @param uri the uri of the molecule file.
@@ -101,11 +104,6 @@ Loads a molecule from the provided data using OpenBabel.
 */
 	void LoadData (char const *data, char const *mime_type);
 
-/*!
-@return the title of the molecule if any.
-*/
-	const char *GetTitle () {return m_Mol.GetTitle ();}
-
 /*!
 @param filename the name of the vrml file to which the data should be written.
 
@@ -113,8 +111,10 @@ Exports the embedded molecule as a vrml scene.
 */
 	void OnExportVRML (std::string const &filename);
 
+	void Clear ();
+
 private:
-	OpenBabel::OBMol m_Mol;
+	Molecule *m_Mol;
 
 /*!\fn SetDisplay3D(Display3DMode mode)
 @param mode: the new mode.
