@@ -24,30 +24,36 @@
 
 #include "config.h"
 #include "bondtool.h"
-#include <gcp/settings.h>
-#include <gcp/document.h>
 #include <gcp/application.h>
 #include <gcp/atom.h>
 #include <gcp/bond.h>
+#include <gcp/document.h>
 #include <gcp/fragment.h>
+#include <gcp/settings.h>
 #include <gcp/theme.h>
-#include <canvas/gcp-canvas-group.h>
+#include <gcp/view.h>
+#include <gccv/canvas.h>
+#include <gccv/group.h>
+#include <gccv/hash.h>
+#include <gccv/line.h>
+#include <gccv/squiggle.h>
+#include <gccv/wedge.h>
+#include <gcu/ui-builder.h>
 #include <glib/gi18n-lib.h>
 #include <cmath>
 
 using namespace gcu;
+using namespace gccv;
 using namespace std;
 
-gcpBondTool::gcpBondTool (gcp::Application *App, string ToolId, unsigned nPoints): gcp::Tool (App, ToolId)
+gcpBondTool::gcpBondTool (gcp::Application *App, string ToolId, G_GNUC_UNUSED unsigned nPoints): gcp::Tool (App, ToolId)
 {
-	points = (nPoints)? gnome_canvas_points_new (nPoints): NULL;
 	m_pOp = NULL;
 	m_AutoDir = false;
 }
 
 gcpBondTool::~gcpBondTool ()
 {
-	if (points) gnome_canvas_points_free (points);
 }
 
 bool gcpBondTool::OnClicked ()
@@ -56,7 +62,6 @@ bool gcpBondTool::OnClicked ()
 		return false;
 	int i;
 	m_pAtom = NULL;
-	m_pItem = NULL;
 	m_bChanged = false;
 	m_dAngle = 0.;
 	gcp::Bond* pBond;
@@ -78,21 +83,19 @@ bool gcpBondTool::OnClicked ()
 			m_y0 *= m_dZoomFactor;
 			m_x1 *= m_dZoomFactor;
 			m_y1 *= m_dZoomFactor;
-			points->coords[0] = m_x0;
-			points->coords[1] = m_y0;
 			m_bChanged = true;
 			m_pOp = pDoc->GetNewOperation (gcp::GCP_MODIFY_OPERATION);
 			m_pOp->AddObject (m_pObjectGroup, 0);
 			UpdateBond ();
 			return true;
+		case FragmentType:
+			m_pObject = static_cast <gcp::Fragment *> (m_pObject)->GetAtom ();
 		case AtomType:
 			if (!((gcp::Atom*) m_pObject)->AcceptNewBonds ())
 				return false;
 			((gcp::Atom*) m_pObject)->GetCoords (&m_x0, &m_y0, NULL);
 			m_x0 *= m_dZoomFactor;
 			m_y0 *=  m_dZoomFactor;
-			points->coords[0] = m_x0;
-			points->coords[1] = m_y0;
 			/* search  preferred orientation for new bond */
 			i = ((gcp::Atom*) m_pObject)->GetBondsNumber ();
 			switch (i) {
@@ -131,20 +134,14 @@ bool gcpBondTool::OnClicked ()
 			return false;
 		}
 	}
-	else if (points)
-	{
-		points->coords[0] = m_x0;
-		points->coords[1] = m_y0;
-	}
 	double a = m_dAngle * M_PI / 180.;
 	m_x1 =  m_x0 + pDoc->GetBondLength () * m_dZoomFactor * cos (a);
 	m_y1 =  m_y0 - pDoc->GetBondLength () * m_dZoomFactor * sin (a);
-	GnomeCanvasItem* pItem = gnome_canvas_get_item_at (GNOME_CANVAS (m_pWidget), m_x1, m_y1);
-	if (pItem == (GnomeCanvasItem*) m_pBackground)
-		pItem = NULL;
+	// TODO: reimplement
+	Item *pItem = m_pView->GetCanvas ()->GetItemAt (m_x1, m_y1);
 	Object* pObject = NULL;
 	if (pItem)
-		pObject = (Object*) g_object_get_data (G_OBJECT (pItem), "object");
+		pObject = dynamic_cast <Object *> (pItem->GetClient ());
 	m_pAtom = NULL;
 	if (pObject && pObject != m_pObject) {
 		if ((pObject->GetType () == BondType) || (pObject->GetType () == FragmentType))
@@ -155,6 +152,14 @@ bool gcpBondTool::OnClicked ()
 		}
 	}
 	if (m_pAtom) {
+		if (m_pObject) {
+			Object *group = m_pObject->GetMolecule ()->GetParent ();
+			if (group != pDoc) {
+				Object *other = m_pAtom->GetMolecule ()->GetParent ();
+				if (other != pDoc && group != other)
+					return true;
+			}
+		}
 		m_pAtom->GetCoords(&m_x1, &m_y1, NULL);
 		m_x1 *= m_dZoomFactor;
 		m_y1 *= m_dZoomFactor;
@@ -172,33 +177,23 @@ bool gcpBondTool::OnClicked ()
 
 void gcpBondTool::OnDrag ()
 {
-	double x1, y1, x2, y2;
 	gcp::Document* pDoc = m_pView->GetDoc ();
 	gcp::Theme *Theme = pDoc->GetTheme ();
 	if ((m_pObject) && (m_pObject->GetType () == BondType)) {
 		if (((gcp::Bond*) m_pObject)->GetDist (m_x / m_dZoomFactor, m_y / m_dZoomFactor) < (Theme->GetPadding () + Theme->GetBondWidth () / 2) * m_dZoomFactor) {
 			if (!m_bChanged) {
-				gnome_canvas_item_show (m_pItem);
+				m_Item->SetVisible (true);
 				m_bChanged = true;
 			}
 		} else if (m_bChanged) {
-			gnome_canvas_item_hide (m_pItem);
+			m_Item->SetVisible (false);
 			m_bChanged = false;
 		}
 	} else {
-		if (m_pItem) {
-			gnome_canvas_item_get_bounds (GNOME_CANVAS_ITEM (m_pItem), &x1, &y1, &x2, &y2);
-			gtk_object_destroy (GTK_OBJECT (GNOME_CANVAS_ITEM (m_pItem)));
-			gnome_canvas_request_redraw (GNOME_CANVAS (m_pWidget), (int) x1, (int) y1, (int) x2, (int) y2);
-			m_pItem = NULL;
-		}
-
-		GnomeCanvasItem* pItem = gnome_canvas_get_item_at (GNOME_CANVAS (m_pWidget), m_x, m_y);
-		if (pItem == (GnomeCanvasItem*) m_pBackground)
-			pItem = NULL;
+		Item *pItem = m_pView->GetCanvas ()->GetItemAt (m_x, m_y);
 		Object* pObject = NULL;
 		if (pItem) {
-			pObject = (Object*) g_object_get_data (G_OBJECT (pItem), "object");
+			pObject = dynamic_cast <Object *> (pItem->GetClient ());
 			if (pObject && (pObject == m_pObject || ((pObject->GetType () == FragmentType) && dynamic_cast<gcp::Fragment*> (pObject)->GetAtom () == m_pObject))) {
 				if (!m_AutoDir)
 					return;
@@ -214,12 +209,10 @@ void gcpBondTool::OnDrag ()
 						pDoc->GetBondAngle (): -pDoc->GetBondAngle ());
 			m_x = m_x1 = m_x0 + pDoc->GetBondLength () * m_dZoomFactor * cos (m_dAngle / 180 * M_PI);
 			m_y = m_y1 = m_y0 - pDoc->GetBondLength () * m_dZoomFactor * sin (m_dAngle / 180 * M_PI);
-			pItem = gnome_canvas_get_item_at (GNOME_CANVAS (m_pWidget), m_x, m_y);
-			if (pItem == (GnomeCanvasItem*) m_pBackground)
-				pItem = NULL;
+			pItem = m_pView->GetCanvas ()->GetItemAt (m_x, m_y);
 			pObject = NULL;
 			if (pItem)
-				pObject = (Object*) g_object_get_data (G_OBJECT (pItem), "object");
+				pObject = dynamic_cast <Object *> (pItem->GetClient ());
 		}
 		m_pAtom = NULL;
 		if (gcp::MergeAtoms && pObject) {
@@ -231,6 +224,14 @@ void gcpBondTool::OnDrag ()
 				m_pAtom = (gcp::Atom*) pObject;
 		}
 		if (m_pAtom) {
+			if (m_pObject) {
+				Object *group = m_pObject->GetMolecule ()->GetParent ();
+				if (group != pDoc) {
+					Object *other = m_pAtom->GetMolecule ()->GetParent ();
+					if (other != pDoc && group != other)
+						return;
+				}
+			}
 			if ((Object*) m_pAtom == m_pObject)
 				return;
 			if (!m_pAtom->AcceptNewBonds ())
@@ -263,7 +264,7 @@ void gcpBondTool::OnDrag ()
 			}
 			m_dAngle = dAngle;
 			if (m_nState & GDK_SHIFT_MASK) {
-				x1 = sqrt (square (m_x) + square (m_y));
+				double x1 = sqrt (square (m_x) + square (m_y));
 				m_x1 = m_x0 + x1 * cos (m_dAngle / 180 * M_PI);
 				m_y1 = m_y0 - x1 * sin (m_dAngle / 180 * M_PI);
 			} else {
@@ -282,13 +283,10 @@ void gcpBondTool::OnDrag ()
 
 void gcpBondTool::OnRelease ()
 {
-	double x1, y1, x2, y2;
 	gcp::Document* pDoc = m_pView->GetDoc ();
-	if (m_pItem) {
-		gnome_canvas_item_get_bounds (GNOME_CANVAS_ITEM (m_pItem), &x1, &y1, &x2, &y2);
-		gtk_object_destroy (GTK_OBJECT(GNOME_CANVAS_ITEM (m_pItem)));
-		gnome_canvas_request_redraw (GNOME_CANVAS (m_pWidget), (int) x1, (int) y1, (int) x2, (int) y2);
-		m_pItem = NULL;
+	if (m_Item) {
+		delete m_Item;
+		m_Item = NULL;
 	} else {
 		if (m_pOp)
 			pDoc->AbortOperation ();
@@ -314,12 +312,10 @@ void gcpBondTool::OnRelease ()
 		m_pOp = NULL;
 	}
 	m_pApp->ClearStatus ();
-	GnomeCanvasItem* pItem = gnome_canvas_get_item_at (GNOME_CANVAS (m_pWidget), m_x1, m_y1);
-	if (pItem == (GnomeCanvasItem*) m_pBackground)
-		pItem = NULL;
+	Item *pItem = m_pView->GetCanvas ()->GetItemAt (m_x1, m_y1);
 	Object* pObject = NULL;
 	if (pItem)
-		pObject = (Object*) g_object_get_data (G_OBJECT (pItem), "object");
+		pObject = dynamic_cast <Object *> (pItem->GetClient ());
 	m_pAtom = NULL;
 	if (gcp::MergeAtoms && pObject) {
 		if (pObject->GetType () == BondType)
@@ -347,7 +343,7 @@ void gcpBondTool::OnRelease ()
 				ModifiedObjects.clear ();
 				return;
 			}
-			pObject = m_pObject->GetGroup ();
+			pObject = m_pAtom->GetGroup ();
 			if (!pObject)
 				throw runtime_error (_("Invalid document tree, please file a bug report"));
 			ModifiedObjects.insert (pObject->GetId ());
@@ -405,58 +401,53 @@ void gcpBondTool::OnRelease ()
 
 void gcpBondTool::Draw ()
 {
-	double x1, y1, x2, y2;
 	gcp::Theme *pTheme = m_pView->GetDoc ()->GetTheme ();
-	points->coords[2] = m_x1;
-	points->coords[3] = m_y1;
-	m_pItem = gnome_canvas_item_new (
-								m_pGroup,
-								gnome_canvas_line_get_type (),
-								"points", points,
-								"fill_color", gcp::AddColor,
-								"width_units", pTheme->GetBondWidth (),
-								NULL);
-	gnome_canvas_item_get_bounds (GNOME_CANVAS_ITEM (m_pItem), &x1, &y1, &x2, &y2);
-	gnome_canvas_request_redraw (GNOME_CANVAS (m_pWidget), (int) x1, (int) y1, (int) x2, (int) y2);
+	if (m_Item) {
+		static_cast <Line *> (m_Item)->SetPosition (m_x0, m_y0, m_x1, m_y1);
+	} else {
+		m_Item = new gccv::Line (m_pView->GetCanvas (), m_x0, m_y0, m_x1, m_y1);
+		static_cast <LineItem *> (m_Item)->SetLineColor (gcp::AddColor);
+		static_cast <LineItem *> (m_Item)->SetLineWidth (pTheme->GetBondWidth ());
+	}
 }
 
 void gcpBondTool::UpdateBond()
 {
 	double x1, y1, x2, y2;
-	int i = 1;
 	gcp::Theme *pTheme = m_pView->GetDoc ()->GetTheme ();
-	BondOrder = ((gcp::Bond*) m_pObject)->GetOrder ();
-	if (((gcp::Bond*) m_pObject)->GetType () == gcp::NormalBondType)
-		((gcp::Bond*) m_pObject)->IncOrder ();
-	m_pItem = gnome_canvas_item_new (m_pGroup, gnome_canvas_group_ext_get_type (), NULL);
-	while (((gcp::Bond*) m_pObject)->GetLine2DCoords (i++, &x1, &y1, &x2, &y2)) {
-		points->coords[0] = x1 * m_dZoomFactor;
-		points->coords[1] = y1 * m_dZoomFactor;
-		points->coords[2] = x2 * m_dZoomFactor;
-		points->coords[3] = y2 * m_dZoomFactor;
-		gnome_canvas_item_new (
-						GNOME_CANVAS_GROUP (m_pItem),
-						gnome_canvas_line_get_type (),
-						"points", points,
-						"fill_color", gcp::AddColor,
-						"width_units", pTheme->GetBondWidth (),
-						NULL);
+	gcp::Bond *bond = static_cast <gcp::Bond *> (m_pObject);
+	BondOrder = bond->GetOrder ();
+	if (bond->GetType () == gcp::NormalBondType)
+		bond->IncOrder ();
+	if (m_Item)
+		delete m_Item;
+	if (bond->GetOrder () == 1) {
+		bond->GetLine2DCoords (1, &x1, &y1, &x2, &y2);
+		m_Item = new gccv::Line (m_pView->GetCanvas (), x1, y1, x2, y2);
+		static_cast <LineItem *> (m_Item)->SetLineColor (gcp::AddColor);
+		static_cast <LineItem *> (m_Item)->SetLineWidth (pTheme->GetBondWidth ());
+	} else {
+		int i = 1;
+		m_Item = new gccv::Group (m_pView->GetCanvas ());
+		while (((gcp::Bond*) m_pObject)->GetLine2DCoords (i++, &x1, &y1, &x2, &y2)) {
+			gccv::LineItem *item = new gccv::Line (static_cast <gccv::Group *> (m_Item),
+												   x1 * m_dZoomFactor, y1 * m_dZoomFactor,
+												   x2 * m_dZoomFactor, y2 * m_dZoomFactor);
+			item->SetLineColor (gcp::AddColor);
+			item->SetLineWidth (pTheme->GetBondWidth ());
+		}
 	}
-	gnome_canvas_item_get_bounds (GNOME_CANVAS_ITEM (m_pItem), &x1, &y1, &x2, &y2);
-	gnome_canvas_request_redraw (GNOME_CANVAS (m_pWidget), (int) x1, (int) y1, (int) x2, (int) y2);
 }
 
 void gcpBondTool::FinalizeBond ()
 {
 	if (m_bChanged) {
 		gcp::Bond* pBond = (gcp::Bond*) m_pObject;
-		if (pBond->GetType () == gcp::NormalBondType) {
-			pBond->Revert ();
+		if (pBond->GetType () == gcp::NormalBondType)
 			m_pView->Update (m_pObject);
-		} else {
+		else {
 			pBond->SetType (gcp::NormalBondType);
-			m_pView->Remove (m_pObject);
-			m_pView->AddObject (m_pObject);
+			m_pView->Update (m_pObject);
 		}
 	}
 	else ((gcp::Bond*) m_pObject)->SetOrder (BondOrder);
@@ -496,14 +487,16 @@ void gcpBondTool::SetLength (double length)
 
 GtkWidget *gcpBondTool::GetPropertyPage ()
 {
-	GladeXML *xml = glade_xml_new (GLADEDIR"/bond.glade", "bond", GETTEXT_PACKAGE);
-	m_LengthBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "bond-length"));
+	gcu::UIBuilder *builder = new gcu::UIBuilder (UIDIR"/bond.ui", GETTEXT_PACKAGE);
+	m_LengthBtn = GTK_SPIN_BUTTON (builder->GetWidget ("bond-length"));
 	g_signal_connect (m_LengthBtn, "value-changed", G_CALLBACK (on_length_changed), this);
-	m_AngleBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "bond-angle"));
+	m_AngleBtn = GTK_SPIN_BUTTON (builder->GetWidget ("bond-angle"));
 	g_signal_connect (m_AngleBtn, "value-changed", G_CALLBACK (on_angle_changed), this);
-	m_MergeBtn = GTK_TOGGLE_BUTTON (glade_xml_get_widget (xml, "merge"));
+	m_MergeBtn = GTK_TOGGLE_BUTTON (builder->GetWidget ("merge"));
 	g_signal_connect (m_MergeBtn, "toggled", G_CALLBACK (on_merge_toggled), NULL);
-	return glade_xml_get_widget (xml, "bond");
+	GtkWidget *res = builder->GetRefdWidget ("bond");
+	delete builder;
+	return res;
 }
 
 void gcpBondTool::Activate ()
@@ -524,25 +517,13 @@ gcpUpBondTool::~gcpUpBondTool ()
 
 void gcpUpBondTool::Draw ()
 {
-	double dx, dy, x1, y1, x2, y2;
-	gcp::Theme *Theme = m_pView->GetDoc ()->GetTheme ();
-	x1 = sqrt (square (m_x1 - m_x0) + square (m_y1 - m_y0));
-	if (x1 == 0)
-		return;
-	dx = (m_y0 - m_y1) / x1 * Theme->GetStereoBondWidth () / 2;
-	dy = (m_x1 - m_x0) / x1 * Theme->GetStereoBondWidth () / 2;
-	points->coords[2] = m_x1 + dx;
-	points->coords[3] = m_y1 + dy;
-	points->coords[4] = m_x1 - dx;
-	points->coords[5] = m_y1 - dy;
-	m_pItem = gnome_canvas_item_new (
-								m_pGroup,
-								gnome_canvas_polygon_get_type (),
-								"points", points,
-								"fill_color", gcp::AddColor,
-								NULL);
-	gnome_canvas_item_get_bounds (GNOME_CANVAS_ITEM (m_pItem), &x1, &y1, &x2, &y2);
-	gnome_canvas_request_redraw (GNOME_CANVAS (m_pWidget), (int) x1, (int) y1, (int) x2, (int) y2);
+	gcp::Theme *pTheme = m_pView->GetDoc ()->GetTheme ();
+	if (m_Item) {
+		static_cast <Wedge *> (m_Item)->SetPosition (m_x0, m_y0, m_x1, m_y1);
+	} else {
+		m_Item = new Wedge (m_pView->GetCanvas (), m_x0, m_y0, m_x1, m_y1, pTheme->GetStereoBondWidth ());
+		static_cast <Wedge *> (m_Item)->SetFillColor (gcp::AddColor);
+	}
 }
 
 void gcpUpBondTool::UpdateBond ()
@@ -554,8 +535,6 @@ void gcpUpBondTool::UpdateBond ()
 		m_y = m_y0;
 		m_y0 = m_y1;
 		m_y1 = m_y;
-		points->coords[0] = m_x0;
-		points->coords[1] = m_y0;
 	}
 	Draw ();
 }
@@ -590,59 +569,18 @@ gcpDownBondTool::~gcpDownBondTool ()
 
 void gcpDownBondTool::Draw()
 {
-	double dx, dy, dx1, dy1, length;
 	gcp::Theme *pTheme = m_pView->GetDoc ()->GetTheme ();
-	m_pItem = gnome_canvas_item_new (m_pGroup, gnome_canvas_group_ext_get_type (), NULL);
-	length = sqrt (square (m_x1 - m_x0) + square (m_y1 - m_y0));
-	if (length == 0.0)
-		return;
-	int n = int (floor (length / (pTheme->GetHashDist () + pTheme->GetHashWidth ())));
-	dx1 = (m_x1 - m_x0) / length * pTheme->GetHashWidth ();
-	dy1 = (m_y1 - m_y0) / length * pTheme->GetHashWidth ();
-	dx = (m_y0 - m_y1) / length * pTheme->GetStereoBondWidth () / 2;
-	dy = (m_x1 - m_x0) / length * pTheme->GetStereoBondWidth () / 2;
-	points->coords[0] = m_x0 + dx;
-	points->coords[1] = m_y0 + dy;
-	points->coords[2] = m_x0 - dx;
-	points->coords[3] = m_y0 - dy;
-	dx *= (1 - pTheme->GetHashWidth () / length);
-	dy *= (1 - pTheme->GetHashWidth () / length);
-	points->coords[4] = m_x0 + dx1 - dx;
-	points->coords[5] = m_y0 + dy1 - dy;
-	points->coords[6] = m_x0 + dx1 + dx;
-	points->coords[7] = m_y0 + dy1 + dy;
-	dx = (m_x1 - m_x0) / length * (pTheme->GetHashDist () + pTheme->GetHashWidth ())
-		- (m_y0 - m_y1) / length * pTheme->GetStereoBondWidth () / 2 * (pTheme->GetHashDist () + pTheme->GetHashWidth ()) / length;
-	dy = (m_y1 - m_y0) / length * (pTheme->GetHashDist () + pTheme->GetHashWidth ())
-		- (m_x1 - m_x0) / length * pTheme->GetStereoBondWidth () / 2 *  (pTheme->GetHashDist () + pTheme->GetHashWidth ()) / length;
-	dx1 = (m_x1 - m_x0) / length * (pTheme->GetHashDist () + pTheme->GetHashWidth ())
-		+ (m_y0 - m_y1) / length * pTheme->GetStereoBondWidth () / 2 *  (pTheme->GetHashDist () + pTheme->GetHashWidth ()) / length;
-	dy1 = (m_y1 - m_y0) / length * (pTheme->GetHashDist () + pTheme->GetHashWidth ())
-		+ (m_x1 - m_x0) / length * pTheme->GetStereoBondWidth () / 2 *  (pTheme->GetHashDist () + pTheme->GetHashWidth ()) / length;
-	gnome_canvas_item_new (
-						GNOME_CANVAS_GROUP (m_pItem),
-						gnome_canvas_polygon_get_type (),
-						"points", points,
-						"fill_color", gcp::AddColor,
-						NULL);
-	for (int i = 1; i < n; i++) {
-		points->coords[0] += dx;
-		points->coords[1] += dy;
-		points->coords[2] += dx1;
-		points->coords[3] += dy1;
-		points->coords[6] += dx;
-		points->coords[7] += dy;
-		points->coords[4] += dx1;
-		points->coords[5] += dy1;
-		gnome_canvas_item_new (
-						GNOME_CANVAS_GROUP (m_pItem),
-						gnome_canvas_polygon_get_type (),
-						"points", points,
-						"fill_color", gcp::AddColor,
-						NULL);
+	if (m_Item) {
+		static_cast <Hash *> (m_Item)->SetPosition (m_x1, m_y1, m_x0, m_y0);
+	} else {
+		gccv::Hash *hash = gcp::InvertWedgeHashes?
+			new Hash (m_pView->GetCanvas (), m_x0, m_y0, m_x1, m_y1, pTheme->GetStereoBondWidth ()):
+			new Hash (m_pView->GetCanvas (), m_x1, m_y1, m_x0, m_y0, pTheme->GetStereoBondWidth ());
+		hash->SetFillColor (gcp::AddColor);
+		hash->SetLineWidth (pTheme->GetHashWidth ());
+		hash->SetLineDist (pTheme->GetHashDist ());
+		m_Item = hash;
 	}
-	gnome_canvas_item_get_bounds (m_pItem, &dx, &dy, &dx1, &dy1);
-	gnome_canvas_request_redraw (GNOME_CANVAS (m_pWidget), (int) dx, (int) dy, (int) dx1, (int) dy1);
 }
 
 void gcpDownBondTool::UpdateBond ()
@@ -678,6 +616,14 @@ void gcpDownBondTool::SetType (gcp::Bond* pBond)
 	pBond->SetType (gcp::DownBondType);
 }
 
+void gcpDownBondTool::OnConfigChanged ()
+{
+	GtkWidget *w = m_pApp->GetToolItem ("DownBond");
+	if (!w)
+		return;
+	gtk_tool_button_set_stock_id (GTK_TOOL_BUTTON (w), gcp::InvertWedgeHashes? "gcp_iDownBond": "gcp_DownBond");
+}
+
 gcpForeBondTool::gcpForeBondTool (gcp::Application *App): gcpBondTool (App, "ForeBond", 4)
 {
 }
@@ -688,29 +634,14 @@ gcpForeBondTool::~gcpForeBondTool ()
 
 void gcpForeBondTool::Draw ()
 {
-	double dx, dy, x1, y1, x2, y2;
 	gcp::Theme *pTheme = m_pView->GetDoc ()->GetTheme ();
-	x1 = sqrt (square (m_x1 - m_x0) + square (m_y1 - m_y0));
-	if (x1 == 0)
-		return;
-	dx = (m_y0 - m_y1) / x1 * pTheme->GetStereoBondWidth () / 2;
-	dy = (m_x1 - m_x0) / x1 * pTheme->GetStereoBondWidth () / 2;
-	points->coords[0] = m_x0 + dx;
-	points->coords[1] = m_y0 + dy;
-	points->coords[2] = m_x1 + dx;
-	points->coords[3] = m_y1 + dy;
-	points->coords[4] = m_x1 - dx;
-	points->coords[5] = m_y1 - dy;
-	points->coords[6] = m_x0 - dx;
-	points->coords[7] = m_y0 - dy;
-	m_pItem = gnome_canvas_item_new (
-								m_pGroup,
-								gnome_canvas_polygon_get_type (),
-								"points", points,
-								"fill_color", gcp::AddColor,
-								NULL);
-	gnome_canvas_item_get_bounds (GNOME_CANVAS_ITEM (m_pItem), &x1, &y1, &x2, &y2);
-	gnome_canvas_request_redraw (GNOME_CANVAS (m_pWidget), (int) x1, (int) y1, (int) x2, (int) y2);
+	if (m_Item) {
+		static_cast <Line *> (m_Item)->SetPosition (m_x0, m_y0, m_x1, m_y1);
+	} else {
+		m_Item = new gccv::Line (m_pView->GetCanvas (), m_x0, m_y0, m_x1, m_y1);
+		static_cast <LineItem *> (m_Item)->SetLineColor (gcp::AddColor);
+		static_cast <LineItem *> (m_Item)->SetLineWidth (pTheme->GetStereoBondWidth ());
+	}
 }
 
 void gcpForeBondTool::UpdateBond ()
@@ -745,38 +676,17 @@ gcpSquiggleBondTool::~gcpSquiggleBondTool ()
 
 void gcpSquiggleBondTool::Draw ()
 {
-	GnomeCanvasPathDef *path_def;
 	gcp::Theme *pTheme = m_pView->GetDoc ()->GetTheme ();
-	path_def = gnome_canvas_path_def_new ();
-	gnome_canvas_path_def_moveto (path_def, m_x0, m_y0);
-	double x = m_x0, y = m_y0, dx, dy, length, x1, x2, y1, y2;
-	length = sqrt (square (m_x1 - m_x0) + square (m_y1 - m_y0));
-	int n = (int)length / 3, s = 1;
-	dx = (m_x1 - m_x0) / n;
-	dy = (m_y1 - m_y0) / n;
-	for (int i = 1; i < n; i++) {
-		x1 = x + dx / 3 + dy /1.5 * s;
-		y1 = y + dy / 3 - dx /1.5 * s;
-		x2 = x + dx / 1.5 + dy /1.5 * s;
-		y2 = y + dy / 1.5 - dx /1.5 * s;
-		x += dx;
-		y += dy;
-		s *= -1;
-		gnome_canvas_path_def_curveto (path_def, x1, y1, x2, y2, x, y);
+	if (m_Item) {
+		static_cast <Squiggle *> (m_Item)->SetPosition (m_x0, m_y0, m_x1, m_y1);
+	} else {
+		Squiggle *squiggle = new Squiggle (m_pView->GetCanvas (), m_x0, m_y0, m_x1, m_y1);
+		squiggle->SetLineColor (gcp::AddColor);
+		squiggle->SetLineWidth (pTheme->GetBondWidth ());
+		squiggle->SetWidth (pTheme->GetStereoBondWidth () - pTheme->GetBondWidth () / 2.);
+		squiggle->SetStep (pTheme->GetHashDist ());
+		m_Item = squiggle;
 	}
-	x1 = x + dx / 3 + dy /1.5 * s;
-	y1 = y + dy / 3 - dx /1.5 * s;
-	x2 = x + dx / 1.5 + dy /1.5 * s;
-	y2 = y + dy / 1.5 - dx /1.5 * s;
-	gnome_canvas_path_def_curveto (path_def, x1, y1, x2, y2, m_x1, m_y1);
-	m_pItem = gnome_canvas_item_new (
-								m_pGroup,
-								gnome_canvas_bpath_get_type (),
-								"outline_color", gcp::AddColor,
-								"width_units", pTheme->GetBondWidth (),
-								"bpath", path_def,
-								NULL);
-	gnome_canvas_path_def_unref (path_def);
 }
 
 void gcpSquiggleBondTool::UpdateBond ()
