@@ -33,38 +33,10 @@
 #include <gcu/molecule.h>
 #include <gcu/printable.h>
 #include <gcu/print-setup-dlg.h>
+#include <gcu/ui-builder.h>
 #include <gcu/residue.h>
 #include <gcu/value.h>
 #include <glib/gi18n.h>
-#include <glade/glade.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkmessagedialog.h>
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtkaboutdialog.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkbox.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkclipboard.h>
-#include <goffice/goffice.h>
-#include <goffice/app/go-plugin.h>
-#include <goffice/app/go-plugin-loader-module.h>
-#include <goffice/data/go-data-simple.h>
-#include <goffice/gtk/go-graph-widget.h>
-#include <goffice/gtk/goffice-gtk.h>
-#include <goffice/graph/gog-axis.h>
-#include <goffice/graph/gog-data-set.h>
-#include <goffice/graph/gog-object.h>
-#include <goffice/graph/gog-plot.h>
-#include <goffice/graph/gog-series.h>
-#include <goffice/graph/gog-style.h>
-#include <goffice/graph/gog-styled-object.h>
-#include <goffice/utils/go-locale.h>
-#include <goffice/utils/go-image.h>
-#include <goffice/utils/go-line.h>
-#include <goffice/utils/go-marker.h>
 #include <gsf/gsf-input-memory.h>
 #include <gsf/gsf-output-memory.h>
 #include <gsf/gsf-output-gio.h>
@@ -97,9 +69,11 @@ public:
 	void DoPrint (GtkPrintOperation *print, GtkPrintContext *context, int page) const;
 	void OnSaveAsImage ();
 	bool FileProcess (const gchar* filename, const gchar* mime_type, bool bSave, GtkWindow *window, Document *pDoc = NULL);
+	static void OnSize (GChemCalc *calc, GtkAllocation *allocation);
 
 private:
 	void ParseNodes (xmlNodePtr node);
+	int m_GraphWidth, m_GraphHeight;
 GCU_PROP (GtkUIManager *, UIManager)
 };
 
@@ -173,8 +147,8 @@ void GChemCalc::DoPrint (G_GNUC_UNUSED GtkPrintOperation *print, GtkPrintContext
 	height = gtk_print_context_get_height (context);
 
 	int w, h; // size in points
-	w = graph_widget->allocation.width;
-	h = graph_widget->allocation.height;
+	w = m_GraphWidth;
+	h = m_GraphHeight;
 	switch (GetScaleType ()) {
 	case GCU_PRINT_SCALE_NONE:
 		break;
@@ -229,7 +203,7 @@ bool GChemCalc::FileProcess (const gchar* filename, const gchar* mime_type, bool
 			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), unescaped);
 			g_free (unescaped);
 			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
-			gtk_window_set_icon_name (GTK_WINDOW (Box), "gspectrum");
+			gtk_window_set_icon_name (GTK_WINDOW (Box), "gchemcalc");
 			result = gtk_dialog_run (Box);
 			gtk_widget_destroy (GTK_WIDGET (Box));
 			g_free (message);
@@ -257,6 +231,12 @@ bool GChemCalc::FileProcess (const gchar* filename, const gchar* mime_type, bool
 	return false;
 }
 
+void GChemCalc::OnSize (GChemCalc *calc, GtkAllocation *allocation)
+{
+	calc->m_GraphWidth = allocation->width;
+	calc->m_GraphHeight = allocation->height;
+}
+
 GChemCalc *App;
 
 static void on_quit (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED void *data)
@@ -509,7 +489,7 @@ static void on_get_data (G_GNUC_UNUSED GtkClipboard *clipboard, GtkSelectionData
 			go_locale_untranslated_booleans ();
 		
 			xout = gsf_xml_out_new (output);
-			gog_object_write_xml_sax (GOG_OBJECT (graph), xout);
+			gog_object_write_xml_sax (GOG_OBJECT (graph), xout, NULL);
 			g_object_unref (xout);
 		
 			/* go_setlocale restores bools to locale translation */
@@ -540,7 +520,7 @@ static void on_get_data (G_GNUC_UNUSED GtkClipboard *clipboard, GtkSelectionData
 		g_object_unref (output);
 		g_free (format);
 		gtk_selection_data_set (selection_data,
-					selection_data->target, 8,
+					gtk_selection_data_get_target (selection_data), 8,
 					(guchar *) buffer, osize);
 		g_free (buffer);
 	}
@@ -727,15 +707,15 @@ int main (int argc, char *argv[])
 	App = new GChemCalc ();
 	
 	/* Initialize plugins manager */
-	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_PLUGIN_LOADER_MODULE_TYPE);
+	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_TYPE_PLUGIN_LOADER_MODULE);
 
-	GladeXML *xml =  glade_xml_new (GLADEDIR"/gchemcalc.glade", "gchemcalc", NULL);
-	App->window = GTK_WINDOW (glade_xml_get_widget (xml, "gchemcalc"));
+	UIBuilder *builder = new UIBuilder (UIDIR"/gchemcalc.ui", GETTEXT_PACKAGE);
+	App->window = GTK_WINDOW (builder->GetRefdWidget ("gchemcalc"));
 	g_signal_connect (GTK_OBJECT (App->window), "destroy",
 		 G_CALLBACK (gtk_main_quit),
 		 NULL);
 	
-	GtkWidget *vbox = glade_xml_get_widget (xml, "vbox1");
+	GtkWidget *vbox = builder->GetWidget ("vbox1");
 	GtkUIManager *ui_manager = gtk_ui_manager_new ();
 	App->SetUIManager (ui_manager);
 	GtkActionGroup *action_group = gtk_action_group_new ("MenuActions");
@@ -753,13 +733,13 @@ int main (int argc, char *argv[])
 	GtkWidget *bar = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
 	gtk_box_pack_start (GTK_BOX (vbox), bar, FALSE, FALSE, 0);
 	gtk_box_reorder_child (GTK_BOX (vbox), bar, 0);
-	App->markup = GTK_LABEL (glade_xml_get_widget (xml, "markup"));
-	App->raw = GTK_LABEL (glade_xml_get_widget (xml, "raw"));
-	App->weight = GTK_LABEL (glade_xml_get_widget (xml, "weight"));
+	App->markup = GTK_LABEL (builder->GetWidget ("markup"));
+	App->raw = GTK_LABEL (builder->GetWidget ("raw"));
+	App->weight = GTK_LABEL (builder->GetWidget ("weight"));
 
 	//Add composition list
 	App->pclist = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
-	GtkTreeView *tree = GTK_TREE_VIEW (glade_xml_get_widget (xml, "composition"));
+	GtkTreeView *tree = GTK_TREE_VIEW (builder->GetWidget ("composition"));
 	gtk_tree_view_set_model (tree, GTK_TREE_MODEL (App->pclist));
 	g_object_unref (App->pclist);
 	GtkCellRenderer *renderer;
@@ -782,10 +762,11 @@ int main (int argc, char *argv[])
 	gtk_tree_view_append_column (tree, column);
 	
 	// Add isotopic pattern chart
-	App->mono = GTK_LABEL (glade_xml_get_widget (xml, "mono"));
-	App->monomass = GTK_LABEL (glade_xml_get_widget (xml, "monomass"));
-	App->pattern_page = glade_xml_get_widget (xml, "pattern");
+	App->mono = GTK_LABEL (builder->GetWidget ("mono"));
+	App->monomass = GTK_LABEL (builder->GetWidget ("monomass"));
+	App->pattern_page = builder->GetWidget ("pattern");
 	App->graph_widget = go_graph_widget_new (NULL);
+	g_signal_connect_swapped (App->graph_widget, "size-allocate", G_CALLBACK (GChemCalc::OnSize), App);
 	gtk_widget_show (App->graph_widget);
 	gtk_box_pack_end (GTK_BOX (App->pattern_page), App->graph_widget, TRUE, TRUE, 0);
 	App->graph = go_graph_widget_get_graph (GO_GRAPH_WIDGET (App->graph_widget));
@@ -795,7 +776,7 @@ int main (int argc, char *argv[])
 	// Create a series for the plot and populate it with some simple data
 	App->series = gog_plot_new_series (App->plot);
 	gog_object_add_by_name (GOG_OBJECT (App->series), "Vertical drop lines", NULL);
-	GogStyle *style = gog_styled_object_get_style (GOG_STYLED_OBJECT (App->series));
+	GOStyle *style = go_styled_object_get_style (GO_STYLED_OBJECT (App->series));
 	go_marker_set_shape (style->marker.mark, GO_MARKER_NONE);
 	style->marker.auto_shape = false;
 	style->line.dash_type = GO_LINE_NONE;
@@ -806,7 +787,7 @@ int main (int argc, char *argv[])
 	gog_dataset_set_dim (GOG_DATASET (obj), GOG_AXIS_ELEM_MAX, data, &error);
 
 	gtk_widget_hide (App->pattern_page);
-	GtkWidget *w = glade_xml_get_widget (xml, "entry");
+	GtkWidget *w = builder->GetWidget ("entry");
 	g_signal_connect (GTK_OBJECT (w), "activate",
 		 G_CALLBACK (cb_entry_active),
 		 App->window);
@@ -817,10 +798,12 @@ int main (int argc, char *argv[])
 		cb_entry_active (GTK_ENTRY (w), App->window);
 	}
 
-	w = glade_xml_get_widget (xml, "notebook1");
+	w = builder->GetWidget ("notebook1");
 	g_signal_connect (w, "switch-page", G_CALLBACK (on_page), NULL);
 	on_page (NULL, NULL, 0); // force menus deactivation
 
+	delete builder;
+
 	gtk_main ();
 	if (graph)
 		g_object_unref (graph);
