@@ -25,13 +25,6 @@
 #include "config.h"
 #include "application.h"
 #include "document.h"
-#ifdef GOFFICE_IS_0_6
-#	include <libgnomevfs/gnome-vfs-init.h>
-#endif
-#include <goffice/goffice.h>
-#include <goffice/app/go-plugin.h>
-#include <goffice/app/go-plugin-loader-module.h>
-#include <goffice/utils/go-file.h>
 #include <gtk/gtkmain.h>
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -43,12 +36,6 @@ int main (int argc, char *argv[])
 
 	textdomain (GETTEXT_PACKAGE);
 	gtk_init (&argc, &argv);
-#ifdef GOFFICE_IS_0_6
-	if (!gnome_vfs_init ()) {
-		printf ("Could not initialize GnomeVFS\n");
-		return 1;
-	}
-#endif
 
 	if (argc > 1 && argv[1][0] == '-') {
 		context = g_option_context_new (_(" [file]"));
@@ -65,7 +52,7 @@ int main (int argc, char *argv[])
 	// create a new Application. This initialize Goffice
 	gsvApplication *App = new gsvApplication ();
 	// Initialize plugins manager
-	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_PLUGIN_LOADER_MODULE_TYPE);
+	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_TYPE_PLUGIN_LOADER_MODULE);
 	gsvDocument *pDoc = App->OnFileNew();
 	char *path, *uri;
 	bool bres = false;
