@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * programs/gchemtable-curve.cc 
  *
- * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -29,30 +29,13 @@
 #include <gcu/chemistry.h>
 #include <gcu/element.h>
 #include <gcu/print-setup-dlg.h>
-#include <goffice/data/go-data-simple.h>
-#include <goffice/gtk/go-graph-widget.h>
-#include <goffice/gtk/goffice-gtk.h>
-#include <goffice/graph/gog-axis.h>
-#include <goffice/graph/gog-data-allocator.h>
-#include <goffice/graph/gog-data-set.h>
-#include <goffice/graph/gog-guru.h>
-#include <goffice/graph/gog-label.h>
-#include <goffice/graph/gog-object.h>
-#include <goffice/graph/gog-plot.h>
-#include <goffice/graph/gog-series.h>
-#include <goffice/graph/gog-style.h>
-#include <goffice/graph/gog-styled-object.h>
-#include <goffice/math/go-math.h>
-#include <goffice/utils/go-locale.h>
-#include <goffice/utils/go-line.h>
-#include <goffice/utils/go-image.h>
-#include <goffice/utils/go-marker.h>
 #include <gsf/gsf-input-memory.h>
 #include <gsf/gsf-output-memory.h>
 #include <gsf/gsf-output-gio.h>
 #include <glib/gi18n.h>
 #include <map>
 #include <cstring>
+#include <sstream>
 
 using namespace gcu;
 using namespace std;
@@ -95,7 +78,7 @@ static void on_get_data (G_GNUC_UNUSED GtkClipboard *clipboard, GtkSelectionData
 			go_locale_untranslated_booleans ();
 		
 			xout = gsf_xml_out_new (output);
-			gog_object_write_xml_sax (GOG_OBJECT (graph), xout);
+			gog_object_write_xml_sax (GOG_OBJECT (graph), xout, NULL);
 			g_object_unref (xout);
 		
 			/* go_setlocale restores bools to locale translation */
@@ -126,7 +109,7 @@ static void on_get_data (G_GNUC_UNUSED GtkClipboard *clipboard, GtkSelectionData
 		g_object_unref (output);
 		g_free (format);
 		gtk_selection_data_set (selection_data,
-					selection_data->target, 8,
+					gtk_selection_data_get_target (selection_data), 8,
 					(guchar *) buffer, osize);
 		g_free (buffer);
 	}
@@ -281,11 +264,11 @@ static const char *ui_description =
 "</ui>";
 
 GChemTableCurve::GChemTableCurve (GChemTableApp *App, char const *name):
-	Dialog (App, GLADEDIR"/curve.glade", "curvedlg", App),
+	Dialog (App, UIDIR"/curve.ui", "curvedlg", GETTEXT_PACKAGE, App),
 	Printable (),
 	m_Guru (NULL)
 {
-	m_GraphBox = glade_xml_get_widget (xml, "vbox1");
+	m_GraphBox = GetWidget ("vbox1");
 	GtkUIManager *ui_manager = gtk_ui_manager_new ();
 	GtkActionGroup *action_group = gtk_action_group_new ("MenuActions");
 	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
@@ -302,6 +285,8 @@ GChemTableCurve::GChemTableCurve (GChemTableApp *App, char const *name):
 	GtkWidget *bar = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
 	gtk_box_pack_start (GTK_BOX (m_GraphBox), bar, FALSE, FALSE, 0);
 	m_GraphWidget = go_graph_widget_new (NULL);
+	g_signal_connect_swapped (m_GraphWidget, "size-allocate", G_CALLBACK (GChemTableCurve::OnSize), this);
+	g_signal_connect_swapped (m_GraphWidget, "motion-notify-event", G_CALLBACK (GChemTableCurve::OnMotion), this);
 	gtk_widget_set_size_request (m_GraphWidget, 400, 250);
 	gtk_widget_show (m_GraphWidget);
 	gtk_box_pack_end (GTK_BOX (m_GraphBox), m_GraphWidget, TRUE, TRUE, 0);
@@ -316,72 +301,56 @@ GChemTableCurve::GChemTableCurve (GChemTableApp *App, char const *name):
 	m_Name = name;
 	// Create a series for the plot and populate it with some simple data
 	GogSeries *series = gog_plot_new_series (plot);
-	double *yvals = g_new0 (double, MAX_ELT);
 	GogObject *obj, *label;
-	GOData *data;
+	GOData *data, *ydata = NULL;
 	int i;
 	// FIXME: find a better way to do the following things !
 	if (!strcmp (name, "en/Pauling")) {
-		GcuElectronegativity en;
-		en.scale = "Pauling";
-		for (i = 1; i <= MAX_ELT; i++) {
-			en.Z = i;
-			yvals[i - 1] = (gcu_element_get_electronegativity (&en))?
-				 				en.value.value: go_nan;
-		}
+		ydata = gct_data_vector_get_from_name (_("Pauling electronegativity"));
 		obj = gog_object_get_child_by_role (GOG_OBJECT (chart),
 				gog_object_find_role_by_name (GOG_OBJECT (chart), "Y-Axis"));
 		data = go_data_scalar_str_new (_("Pauling electronegativity"), FALSE);
-		label = (GogObject*) g_object_new (GOG_LABEL_TYPE, NULL);
+		label = (GogObject*) g_object_new (GOG_TYPE_LABEL, NULL);
 		gog_dataset_set_dim (GOG_DATASET (label), 0, data, &error);
 		gog_object_add_by_name (obj, "Label", label);
 		gtk_window_set_title (dialog, _("Pauling electronegativity"));
 	} else if (!strcmp (name, "ae")) {
-		GcuDimensionalValue const *val;
-		Element *elt;
-		// assuming all data are in kJ/mol
-		for (i = 1; i <= MAX_ELT; i++) {
-			elt = Element::GetElement (i);
-			val = (elt)? elt->GetElectronAffinity (): NULL;
-			yvals[i - 1] = (val)? val->value: go_nan;
-		}
+		ydata = gct_data_vector_get_from_name (_("Electronic affinity"));
 		obj = gog_object_get_child_by_role (GOG_OBJECT (chart),
 				gog_object_find_role_by_name (GOG_OBJECT (chart), "Y-Axis"));
 		data = go_data_scalar_str_new (_("Electron affinity (kJ/mol)"), FALSE);
-		label = (GogObject*) g_object_new (GOG_LABEL_TYPE, NULL);
+		label = (GogObject*) g_object_new (GOG_TYPE_LABEL, NULL);
 		gog_dataset_set_dim (GOG_DATASET (label), 0, data, &error);
 		gog_object_add_by_name (obj, "Label", label);
 		gtk_window_set_title (dialog, _("Electron affinity"));
 	} else if (!strncmp (name, "ei/", 3)) {
 		unsigned rank = strtol (name + 3, NULL, 10);
-		GcuDimensionalValue const *val;
-		Element *elt;
-		// assuming all data are in MJ/mol
-		for (i = 1; i <= MAX_ELT; i++) {
-			elt = Element::GetElement (i);
-			val = (elt)? elt->GetIonizationEnergy (rank): NULL;
-			yvals[i - 1] = (val)? val->value: go_nan;
-		}
-		char *rk, *buf;
+		char *rk, *buf;		
 		switch (rank) {
 		case 1:
+			ydata = gct_data_vector_get_from_name (_("First ionization energy"));
 			rk = g_strdup (_("1st. "));
 			break;
 		case 2:
+			ydata = gct_data_vector_get_from_name (_("Second ionization energy"));
 			rk = g_strdup (_("2nd. "));
 			break;
 		case 3:
+			ydata = gct_data_vector_get_from_name (_("Third ionization energy"));
 			rk = g_strdup (_("3rd. "));
 			break;
 		default:
 			rk = g_strdup_printf (_("%dth. "), rank);
+			buf = g_strconcat (rk, "ionization energy", NULL);
+//			ydata = gct_vector_get_ionization_energies (buf); // FIXME: not implemented
+			g_free (buf);
 			break;
 		}
 		buf = g_strconcat (rk, _("ionization energy (MJ/mol)"), NULL);
 		obj = gog_object_get_child_by_role (GOG_OBJECT (chart),
 				gog_object_find_role_by_name (GOG_OBJECT (chart), "Y-Axis"));
 		data = go_data_scalar_str_new (buf, TRUE);
-		label = (GogObject*) g_object_new (GOG_LABEL_TYPE, NULL);
+		label = (GogObject*) g_object_new (GOG_TYPE_LABEL, NULL);
 		gog_dataset_set_dim (GOG_DATASET (label), 0, data, &error);
 		gog_object_add_by_name (obj, "Label", label);
 		buf = g_strconcat (rk, _("ionization energy"), NULL);
@@ -389,92 +358,47 @@ GChemTableCurve::GChemTableCurve (GChemTableApp *App, char const *name):
 		g_free (buf);
 		g_free (rk);
 	} else if (!strcmp (name, "covalent")) {
-		Element *elt;
-		GcuAtomicRadius r;
-		r.type = GCU_COVALENT;
-		r.charge = 0;
-		r.scale = NULL;
-		r.cn = -1;
-		r.spin = GCU_N_A_SPIN;
-		for (i = 1; i <= MAX_ELT; i++) {
-			r.Z = i;
-			elt = Element::GetElement (i);
-			yvals[i - 1] = (elt && elt->GetRadius (&r))? r.value.value: go_nan;
-		}
+		ydata = gct_data_vector_get_from_name (_("Covalent radius"));
 		obj = gog_object_get_child_by_role (GOG_OBJECT (chart),
 				gog_object_find_role_by_name (GOG_OBJECT (chart), "Y-Axis"));
 		data = go_data_scalar_str_new (_("Covalent radii"), FALSE);
-		label = (GogObject*) g_object_new (GOG_LABEL_TYPE, NULL);
+		label = (GogObject*) g_object_new (GOG_TYPE_LABEL, NULL);
 		gog_dataset_set_dim (GOG_DATASET (label), 0, data, &error);
 		gog_object_add_by_name (obj, "Label", label);
 		gtk_window_set_title (dialog, _("Covalent radii"));
 	} else if (!strcmp (name, "vdw")) {
-		Element *elt;
-		GcuAtomicRadius r;
-		r.type = GCU_VAN_DER_WAALS;
-		r.charge = 0;
-		r.scale = NULL;
-		r.cn = -1;
-		r.spin = GCU_N_A_SPIN;
-		for (i = 1; i <= MAX_ELT; i++) {
-			r.Z = i;
-			elt = Element::GetElement (i);
-			yvals[i - 1] = (elt && elt->GetRadius (&r))? r.value.value: go_nan;
-		}
+		ydata = gct_data_vector_get_from_name (_("Van der Waals radius"));
 		obj = gog_object_get_child_by_role (GOG_OBJECT (chart),
 				gog_object_find_role_by_name (GOG_OBJECT (chart), "Y-Axis"));
 		data = go_data_scalar_str_new (_("Van der Waals radii"), FALSE);
-		label = (GogObject*) g_object_new (GOG_LABEL_TYPE, NULL);
+		label = (GogObject*) g_object_new (GOG_TYPE_LABEL, NULL);
 		gog_dataset_set_dim (GOG_DATASET (label), 0, data, &error);
 		gog_object_add_by_name (obj, "Label", label);
 		gtk_window_set_title (dialog, _("Van der Waals radii"));
 	} else if (!strcmp (name, "metallic")) {
-		Element *elt;
-		GcuAtomicRadius r;
-		r.type = GCU_METALLIC;
-		r.charge = 0;
-		r.scale = NULL;
-		r.cn = -1;
-		r.spin = GCU_N_A_SPIN;
-		for (i = 1; i <= MAX_ELT; i++) {
-			r.Z = i;
-			elt = Element::GetElement (i);
-			yvals[i - 1] = (elt && elt->GetRadius (&r))? r.value.value: go_nan;
-		}
+		ydata = gct_data_vector_get_from_name (_("Metallic radius"));
 		obj = gog_object_get_child_by_role (GOG_OBJECT (chart),
 				gog_object_find_role_by_name (GOG_OBJECT (chart), "Y-Axis"));
 		data = go_data_scalar_str_new (_("Metallic radii"), FALSE);
-		label = (GogObject*) g_object_new (GOG_LABEL_TYPE, NULL);
+		label = (GogObject*) g_object_new (GOG_TYPE_LABEL, NULL);
 		gog_dataset_set_dim (GOG_DATASET (label), 0, data, &error);
 		gog_object_add_by_name (obj, "Label", label);
 		gtk_window_set_title (dialog, _("Metallic radii"));
 	} else if (!strcmp (name, "mp")) {
-		Element *elt;
-		Value const *prop;
-		for (i = 1; i <= MAX_ELT; i++) {
-			elt = Element::GetElement (i);
-			prop = elt->GetProperty ("meltingpoint");
-			yvals[i - 1] = (prop)? prop->GetAsDouble (): go_nan;
-		}
+		ydata = gct_data_vector_get_from_name (_("Fusion temperature"));
 		obj = gog_object_get_child_by_role (GOG_OBJECT (chart),
 				gog_object_find_role_by_name (GOG_OBJECT (chart), "Y-Axis"));
 		data = go_data_scalar_str_new (_("Melting point"), FALSE);
-		label = (GogObject*) g_object_new (GOG_LABEL_TYPE, NULL);
+		label = (GogObject*) g_object_new (GOG_TYPE_LABEL, NULL);
 		gog_dataset_set_dim (GOG_DATASET (label), 0, data, &error);
 		gog_object_add_by_name (obj, "Label", label);
 		gtk_window_set_title (dialog, _("Melting point"));
 	} else if (!strcmp (name, "bp")) {
-		Element *elt;
-		Value const *prop;
-		for (i = 1; i <= MAX_ELT; i++) {
-			elt = Element::GetElement (i);
-			prop = elt->GetProperty ("boilingpoint");
-			yvals[i - 1] = (prop)? prop->GetAsDouble (): go_nan;
-		}
+		ydata = gct_data_vector_get_from_name (_("Ebullition temperature"));
 		obj = gog_object_get_child_by_role (GOG_OBJECT (chart),
 				gog_object_find_role_by_name (GOG_OBJECT (chart), "Y-Axis"));
 		data = go_data_scalar_str_new (_("Boiling point"), FALSE);
-		label = (GogObject*) g_object_new (GOG_LABEL_TYPE, NULL);
+		label = (GogObject*) g_object_new (GOG_TYPE_LABEL, NULL);
 		gog_dataset_set_dim (GOG_DATASET (label), 0, data, &error);
 		gog_object_add_by_name (obj, "Label", label);
 		gtk_window_set_title (dialog, _("Boiling point"));
@@ -483,20 +407,21 @@ GChemTableCurve::GChemTableCurve (GChemTableApp *App, char const *name):
 		return;
 	}
 	i = MAX_ELT - 1;
-	while (!go_finite (yvals[i]))
-		i--;
-	i++;
+	if (ydata) {
+		while (!go_finite (go_data_vector_get_value (GO_DATA_VECTOR (ydata), i)))
+			i--;
+		i++;
+		gog_series_set_dim (series, 1, ydata, &error);
+	}
 	obj = gog_object_get_child_by_role (GOG_OBJECT (chart),
 			gog_object_find_role_by_name (GOG_OBJECT (chart), "X-Axis"));
 	data = go_data_scalar_val_new ((double) i);
 	gog_dataset_set_dim (GOG_DATASET (obj), GOG_AXIS_ELEM_MAX, data, &error);
-	data = go_data_vector_val_new (yvals, MAX_ELT, g_free);
-	gog_series_set_dim (series, 1, data, &error);
 	gog_series_set_dim (series, 0, gct_data_vector_get_from_name (_("Atomic number")), &error);
 	obj = gog_object_get_child_by_role (GOG_OBJECT (chart),
 			gog_object_find_role_by_name (GOG_OBJECT (chart), "X-Axis"));
 	data = go_data_scalar_str_new ("Z", FALSE);
-	label = (GogObject*) g_object_new (GOG_LABEL_TYPE, NULL);
+	label = (GogObject*) g_object_new (GOG_TYPE_LABEL, NULL);
 	gog_dataset_set_dim (GOG_DATASET (label), 0, data, &error);
 	gog_object_add_by_name (obj, "Label", label);
 }
@@ -518,8 +443,8 @@ void GChemTableCurve::DoPrint (G_GNUC_UNUSED GtkPrintOperation *print, GtkPrintC
 	height = gtk_print_context_get_height (context);
 
 	int w, h; // size in points
-	w = m_GraphWidget->allocation.width;
-	h = m_GraphWidget->allocation.height;
+	w = m_GraphWidth;
+	h = m_GraphHeight;
 	switch (GetScaleType ()) {
 	case GCU_PRINT_SCALE_NONE:
 		break;
@@ -571,7 +496,7 @@ graph_user_config_free_data (gpointer data,
 static void
 on_update_graph (GogGraph *graph, gpointer data)
 {
-	g_return_if_fail (IS_GOG_GRAPH (graph));
+	g_return_if_fail (GOG_IS_GRAPH (graph));
 	GctControlGUI *tcg = GCT_CONTROL_GUI (data);
 	GChemTableCurve *curve = gct_control_gui_get_owner (tcg);
 	curve->SetGraph (graph);
@@ -585,7 +510,7 @@ on_guru_help (Application *app)
 
 void GChemTableCurve::OnProperties ()
 {
-	GctControlGUI *tcg = GCT_CONTROL_GUI (g_object_new (GCT_CONTROL_GUI_TYPE, NULL));
+	GctControlGUI *tcg = GCT_CONTROL_GUI (g_object_new (GCT_TYPE_CONTROL_GUI, NULL));
 	gct_control_gui_set_owner (tcg, this);
 	GClosure *closure = g_cclosure_new (G_CALLBACK (on_update_graph), tcg,
 					(GClosureNotify) graph_user_config_free_data);
@@ -622,3 +547,37 @@ void GChemTableCurve::SaveAsImage (string const &filename, char const *mime_type
 	gog_graph_export_image (graph, format, output, -1., -1.);
 	g_object_unref (graph);
 }
+
+void GChemTableCurve::OnSize (GChemTableCurve *curve, GtkAllocation *allocation)
+{
+	curve->m_GraphWidth = allocation->width;
+	curve->m_GraphHeight = allocation->height;
+}
+
+bool GChemTableCurve::OnMotion (GChemTableCurve *curve, GdkEventMotion *event)
+{
+	GogRenderer *renderer = go_graph_widget_get_renderer (GO_GRAPH_WIDGET (curve->m_GraphWidget));
+	GogView *view;
+	GogObject *obj;
+	GogSeries *series;
+	int index;
+	ostringstream buf;
+	g_object_get (G_OBJECT (renderer), "view", &view, NULL);
+	gog_view_get_view_at_point (view, event->x, event->y, &obj, NULL);
+	if (!obj)
+		goto tooltip;
+	obj = gog_object_get_parent_typed (obj, GOG_TYPE_PLOT);
+	if (!obj)
+		goto tooltip;
+	view = gog_view_find_child_view (view, obj);
+	index = gog_plot_view_get_data_at_point (GOG_PLOT_VIEW (view), event->x, event->y, &series);
+	if (index >=0) {
+		buf << Element::GetElement (index + 1)->GetName ();
+		gtk_widget_set_tooltip_text (curve->m_GraphWidget, buf.str ().c_str ());
+		return true;
+	}
+
+tooltip:
+	gtk_widget_set_tooltip_text (curve->m_GraphWidget, NULL);
+	return true;
+}
